==> disk-file-writer-1.0.0.tgz: package/src/file-worker.ts <==
import DBCreater from './db';

// trick typescript
const DB = DBCreater({});

type WebMWriterType = {
    addFrame(encodedChunk: EncodedVideoChunk | VideoFrame): void;
    complete(): Promise<void>;
}

export default () => {
    const db = new DB('fileHandle', 1);
    const addTimeStamp = (text: string) => {
        return '[' + new Date().toLocaleString() + '] ' + text;
    }
    const breakLine = (text: string) => {
        return text + '\n';
    }
    const getDate = (time?: any) => {
        const _date = time ? new Date(time) : new Date();
        const date = _date.toISOString().split('T')[0];
        return date;
    }

    let videoWriter: WebMWriterType;
    let frameReader: ReadableStreamDefaultReader<VideoFrame>;
    let writableStream: FileSystemWritableFileStream;
    let textFileAccessHandle: FileSystemSyncAccessHandle;
    let encoder: TextEncoder;

    interface IGlobalParams {
        directoryHandle: FileSystemDirectoryHandle | undefined,
        fileSizeQuota: number | undefined,
        filenamePrefix: string | undefined,
        filenameExtension: string | undefined,
        dbKeyForCurrentFileHandle: string | undefined,
        textFileHandle: FileSystemFileHandle | undefined,
        textFileLatestDate: number | undefined,
        syncAccessHandle: FileSystemSyncAccessHandle | undefined,
        intervalHandle: number | undefined,
        maxDaysToKeepFile: number
    }

    type FEntry = FileSystemFileHandle | FileSystemDirectoryHandle;

    const globalParams: IGlobalParams = {
        directoryHandle: undefined,
        fileSizeQuota: undefined,
        filenamePrefix: undefined,
        filenameExtension: undefined,
        dbKeyForCurrentFileHandle: undefined,
        textFileHandle: undefined,
        textFileLatestDate: undefined,
        syncAccessHandle: undefined,
        intervalHandle: undefined,
        maxDaysToKeepFile: 0
    }

    const saveFile = async () => {
        await textFileAccessHandle.flush();
        await textFileAccessHandle.close();
        textFileAccessHandle = null;
    }

    const getFileHandle = async () => {
        const { filenamePrefix, filenameExtension } = globalParams;
        const fileFromDB = await db.getData(globalParams.dbKeyForCurrentFileHandle);
        const fileHandle: FileSystemFileHandle = fileFromDB && fileFromDB.data;
        if (!fileHandle) {
            const date = getDate();
            globalParams.textFileLatestDate = +new Date();
            const fileNameWithDate = `${filenamePrefix}_${date}_00${filenameExtension}`;
            const _textFileHandle = await globalParams.directoryHandle.getFileHandle(fileNameWithDate, { create: true });
            db.putData(_textFileHandle, globalParams.dbKeyForCurrentFileHandle);
            return _textFileHandle;
        }

        try {
            const file = await fileHandle.getFile();
            console.log('get fileHandle from db', file);
        } catch (error) {
            console.log('getFile failed:', error);
            const date = getDate();
            globalParams.textFileLatestDate = +new Date();
            const fileNameWithDate = `${filenamePrefix}_${date}_00${filenameExtension}`;
            const _textFileHandle = await globalParams.directoryHandle.getFileHandle(fileNameWithDate, { create: true });
            db.putData(_textFileHandle, globalParams.dbKeyForCurrentFileHandle);
            return _textFileHandle;
        }
        return fileHandle;
    }

    async function verifyPermission(fileHandle: FileSystemFileHandle, readWrite?: boolean) {
        const options: {
            mode: FileSystemPermissionMode
        } = {
            mode: 'read'
        };
        if (readWrite) {
        options.mode = 'readwrite';
        }
        // Check if permission was already granted. If so, return true.
        if ((await fileHandle.queryPermission(options)) === 'granted') {
        return true;
        }
        // Request permission. If the user grants permission, return true.
        if ((await fileHandle.requestPermission(options)) === 'granted') {
        return true;
        }
        // The user didn't grant permission, so return false.
        return false;
    }


    const createNewFileHandle = async () => {
        const { filenamePrefix, filenameExtension } = globalParams;
        let chunkNum = 0;
        try {
            const file = await globalParams.textFileHandle.getFile();
            chunkNum = (function getChunkNum() {
                const arr = file.name.split('_');
                const _lastChunkNum = arr[arr.length - 1];
                const lastChunkNum = _lastChunkNum.split('.')[0];
                return Number(lastChunkNum) + 1;
            })();
        } catch (error) {
            console.log('getFile failed:', error);
        }
        const date = getDate();
        globalParams.textFileLatestDate = + new Date();
        const fileNameWithDate = `${filenamePrefix}_${date}_${chunkNum}${filenameExtension}`;
        const _textFileHandle = await globalParams.directoryHandle.getFileHandle(fileNameWithDate, { create: true });
        db.putData(_textFileHandle, globalParams.dbKeyForCurrentFileHandle);
        return _textFileHandle;
    }

    async function* getFilesHandleRecursively(entry: FEntry): AsyncGenerator<FileSystemFileHandle> {
        if (entry.kind === 'file') {
            yield entry;
        } else if (entry.kind === 'directory') {
            for await (const handle of entry.values()) {
                yield* getFilesHandleRecursively(handle);
            }
        }
    }

    const rotateLogFile = async () => {
        const beforeMaxDays = globalParams.textFileLatestDate - globalParams.maxDaysToKeepFile * 86400000; // 24 * 3600 * 1000
        const rootDirHandle = await navigator.storage.getDirectory();
        for await (const fileHandle of getFilesHandleRecursively(rootDirHandle)) {
            const lastModified = (await fileHandle.getFile()).lastModified;
            if (lastModified < beforeMaxDays) {
                fileHandle.remove();
            }
        }
    }

    /* eslint-disable */
    self.onmessage = async (e) => {
        switch (e.data?.cmd) {
            case 'startWriteVideoFile':
                const fileHandle: FileSystemFileHandle = e.data.fileHandle;
                const trackSettings = e.data.trackSettings;
                fileHandle.createWritable().then(_writable => {
                    writableStream = _writable;
                    videoWriter = new WebMWriter({
                        fileWriter: writableStream,
                        codec: 'VP9',
                        frameRate: 30,
                        width: trackSettings.width,
                        height: trackSettings.height
                    });
                });
                frameReader = (function getFrameReader() {
                    const frameReadable: ReadableStream<VideoFrame> = e.data.frameReadable;
                    return frameReadable.getReader()
                })();

                const videoEncoder = (function getVideoEncoder() {
                    const init: VideoEncoderInit = {
                        output: (encodedChunk) => {
                            console.log('encodedChunk >>>', encodedChunk);
                            videoWriter?.addFrame(encodedChunk);
                        },
                        error: e => console.error('video encode error:', e)
                    }
                    const videoEncoder = new VideoEncoder(init);

                    videoEncoder.configure({
                        codec: 'vp09.00.10.08',
                        framerate: 30,
                        bitrate: 15e5,
                        width: trackSettings.width,
                        height: trackSettings.height
                    });
                    return videoEncoder;
                })()
                frameReader.read().then(async function processFrame({ done, value }) {
                    if (done) {
                        await videoEncoder.flush();
                        videoEncoder.close();
                        return;
                    }
                    videoEncoder.encode(value);
                    value.close();
                    frameReader?.read().then(processFrame);
                });
                break;

            case 'createLogFile':
                const directoryHandle = globalParams.directoryHandle || await navigator.storage.getDirectory();
                const { filenamePrefix, fileSizeQuota, maxDaysToKeepFile } = e.data;
                globalParams.filenameExtension = filenamePrefix;
                globalParams.filenamePrefix = filenamePrefix;
                globalParams.directoryHandle = directoryHandle;
                globalParams.fileSizeQuota = fileSizeQuota;
                globalParams.maxDaysToKeepFile = maxDaysToKeepFile;
                globalParams.dbKeyForCurrentFileHandle = `${filenamePrefix}_currentFileHandle`;
                const textFileHandle = globalParams.textFileHandle || await getFileHandle();
                textFileAccessHandle = await textFileHandle.createSyncAccessHandle();
                encoder = new TextEncoder();
                self.postMessage({
                    cmd: 'createLogFileReady'
                })
                globalParams.textFileHandle = textFileHandle;
                break;

            case 'logs':
                if (!textFileAccessHandle) {
                    console.warn('file writer has closed');
                    return;
                }
                let fileSize = await textFileAccessHandle.getSize();
                if (fileSize >= globalParams.fileSizeQuota) {
                    await saveFile();
                    const date = getDate();
                    if (date !== getDate(globalParams.textFileLatestDate)) {
                        // a new day, we need to rotate logs
                        rotateLogFile()
                    }
                    const fileHandle = await createNewFileHandle();
                    globalParams.textFileHandle = fileHandle;
                    textFileAccessHandle = await fileHandle.createSyncAccessHandle();
                    fileSize = 0;
                }
                const writeBuffer = encoder.encode(breakLine(addTimeStamp(e.data.text)));
                if (globalParams.syncAccessHandle) {
                    const accessHandle = globalParams.syncAccessHandle;
                    const fsize = await accessHandle.getSize();
                    await accessHandle.write(writeBuffer, { at: fsize });
                }
                textFileAccessHandle.write(writeBuffer, { at: fileSize });
                break;

            case 'clearOPFSFiles':
                {
                    const directoryHandle = await navigator.storage.getDirectory();
                    for await (const fileHandle of getFilesHandleRecursively(directoryHandle)) {
                        const permission = await verifyPermission(fileHandle, true);
                        if (permission) {
                            fileHandle.remove();
                        }
                    }
                    break;
                }

            case 'getOPFSFilesInfoByDate':
                {
                    const startDate = e.data.startDate;
                    const endDate = e.data.endDate;
                    const filesInfo = [];
                    const rootDirHandle = await navigator.storage.getDirectory();
                    for await (const fileHandle of getFilesHandleRecursively(rootDirHandle)) {
                        const file = await fileHandle.getFile();
                        const lastModified = file.lastModified;
                        if (lastModified > startDate && lastModified < endDate) {
                            filesInfo.push(file)                            
                        }
                    }

                    self.postMessage({
                        cmd: 'OPFSFilesInfo',
                        payload: filesInfo
                    })
                    break;
                }

            case 'saveLogFile':
                await saveFile();
                break;

            case 'stopWriteVideoFile':
                await frameReader?.cancel().catch(e => console.log(e, 'frame reader'));
                await videoWriter?.complete().then(res => console.log(res, 'res')).catch(e => console.log(e, 'complete error'));
                writableStream.close();
                break;

            case 'moveOPFSFileByDate':
                const startDate = e.data.startDate;
                const endDate = e.data.endDate;
                const targetDirHandle = e.data.targetDirHandle;
                const rootDirHandle = await navigator.storage.getDirectory();
                for await (const fileHandle of getFilesHandleRecursively(rootDirHandle)) {
                    const lastModified = (await fileHandle.getFile()).lastModified;
                    if (lastModified > startDate && lastModified < endDate) {
                        if (!(globalParams.textFileHandle && await fileHandle.isSameEntry(globalParams.textFileHandle))) {
                            await fileHandle.move(targetDirHandle);
                        } else {
                            console.warn("current file can't be moved because it's not complete");
                        }
                    }
                }
                break;
            case 'moveOPFSFilesByName':
                {
                    const filename = e.data.filename;
                    const targetDirHandle = e.data.targetDirHandle;
                    const rootDirHandle = await navigator.storage.getDirectory();
                    const fileHandle = await rootDirHandle.getFileHandle(filename);
                    if (!(globalParams.textFileHandle && await fileHandle.isSameEntry(globalParams.textFileHandle))) {
                        await fileHandle.move(targetDirHandle);
                    } else {
                        console.warn("current file can't be moved because it's not complete")
                    }
                    break;
                }

            case 'writeRealTimeLog':
                {
                    const directoryHandle = await navigator.storage.getDirectory();
                    const tempLogFileHandle = await directoryHandle.getFileHandle('tempLog.txt', { create: true });

                    const reader = new FileReader();
                    const targetFileHandle = e.data.targetFileHandle;


                    reader.onload = async (event) => {
                        await globalParams.syncAccessHandle.truncate(0);
                        const writable = (await targetFileHandle.createWritable({ keepExistingData: true }));
                        const targetLogFile = await targetFileHandle.getFile();
                        console.log(targetLogFile.size, 'targetLogFile.size');
                        writable.write({ type: "write", position: targetLogFile.size, data: event.target.result });
                        await writable.close();
                    }

                    const syncAccessHandle = await tempLogFileHandle.createSyncAccessHandle();

                    globalParams.intervalHandle = setInterval(async () => {
                        const tempLogFile = await tempLogFileHandle.getFile();
                        reader.readAsArrayBuffer(tempLogFile);
                        reader.abort();
                    }, 1000);

                    globalParams.syncAccessHandle = syncAccessHandle;
                }
                break;

            case 'stopWriteRealTimeLog':
                clearInterval(globalParams.intervalHandle);
                globalParams.syncAccessHandle.flush();
                globalParams.syncAccessHandle.close();
                globalParams.syncAccessHandle = null;
                break;
            default:
                break;
        }
    }

    self.postMessage({
        cmd: 'initOK'
    })
}

==> disk-file-writer-1.0.1.tgz: package/src/file-worker.ts <==
import DBCreater from './db';

// trick typescript
const DB = DBCreater({});

type WebMWriterType = {
    addFrame(encodedChunk: EncodedVideoChunk | VideoFrame): void;
    complete(): Promise<void>;
}

export default () => {
    const db = new DB('fileHandle', 1);
    const addTimeStamp = (text: string) => {
        return '[' + new Date().toLocaleString() + '] ' + text;
    }
    const breakLine = (text: string) => {
        return text + '\n';
    }
    const getDate = (time?: any) => {
        const _date = time ? new Date(time) : new Date();
        const date = _date.toISOString().split('T')[0];
        return date;
    }

    // let videoWriter: WebMWriterType;
    // let frameReader: ReadableStreamDefaultReader<VideoFrame>;
    // let writableStream: FileSystemWritableFileStream;
    let textFileAccessHandle: FileSystemSyncAccessHandle;
    let encoder: TextEncoder;

    interface IGlobalParams {
        directoryHandle: FileSystemDirectoryHandle,
        fileSizeQuota: number,
        filenamePrefix: string,
        filenameExtension: string,
        dbKeyForCurrentFileHandle: string,
        textFileHandle: FileSystemFileHandle,
        textFileLatestDate: number,
        syncAccessHandle: FileSystemSyncAccessHandle,
        intervalHandle: number,
        mediaRecorder: MediaRecorder,
        maxDaysToKeepFile: number
    }

    type FEntry = FileSystemFileHandle | FileSystemDirectoryHandle;

    const globalParams: IGlobalParams = {
        directoryHandle: undefined,
        fileSizeQuota: undefined,
        filenamePrefix: undefined,
        filenameExtension: undefined,
        dbKeyForCurrentFileHandle: undefined,
        textFileHandle: undefined,
        textFileLatestDate: undefined,
        syncAccessHandle: undefined,
        intervalHandle: undefined,
        mediaRecorder: undefined,
        maxDaysToKeepFile: 0
    }

    const saveFile = async () => {
        await textFileAccessHandle.flush();
        await textFileAccessHandle.close();
        textFileAccessHandle = null;
    }

    const getFileHandle = async () => {
        const { filenamePrefix, filenameExtension } = globalParams;
        const fileFromDB = await db.getData(globalParams.dbKeyForCurrentFileHandle);
        const fileHandle: FileSystemFileHandle = fileFromDB && fileFromDB.data;
        if (!fileHandle) {
            const date = getDate();
            globalParams.textFileLatestDate = +new Date();
            const fileNameWithDate = `${filenamePrefix}_${date}_00${filenameExtension}`;
            const _textFileHandle = await globalParams.directoryHandle.getFileHandle(fileNameWithDate, { create: true });
            db.putData(_textFileHandle, globalParams.dbKeyForCurrentFileHandle);
            return _textFileHandle;
        }

        try {
            const file = await fileHandle.getFile();
            console.log('get fileHandle from db', file);
        } catch (error) {
            console.log('getFile failed:', error);
            const date = getDate();
            globalParams.textFileLatestDate = +new Date();
            const fileNameWithDate = `${filenamePrefix}_${date}_00${filenameExtension}`;
            const _textFileHandle = await globalParams.directoryHandle.getFileHandle(fileNameWithDate, { create: true });
            db.putData(_textFileHandle, globalParams.dbKeyForCurrentFileHandle);
            return _textFileHandle;
        }
        return fileHandle;
    }

    async function verifyPermission(fileHandle: FileSystemFileHandle, readWrite?: boolean) {
        const options: {
            mode: FileSystemPermissionMode
        } = {
            mode: 'read'
        };
        if (readWrite) {
        options.mode = 'readwrite';
        }
        // Check if permission was already granted. If so, return true.
        if ((await fileHandle.queryPermission(options)) === 'granted') {
        return true;
        }
        // Request permission. If the user grants permission, return true.
        if ((await fileHandle.requestPermission(options)) === 'granted') {
        return true;
        }
        // The user didn't grant permission, so return false.
        return false;
    }


    const createNewFileHandle = async () => {
        const { filenamePrefix, filenameExtension } = globalParams;
        let chunkNum = 0;
        try {
            const file = await globalParams.textFileHandle.getFile();
            chunkNum = (function getChunkNum() {
                const arr = file.name.split('_');
                const _lastChunkNum = arr[arr.length - 1];
                const lastChunkNum = _lastChunkNum.split('.')[0];
                return Number(lastChunkNum) + 1;
            })();
        } catch (error) {
            console.log('getFile failed:', error);
        }
        const date = getDate();
        globalParams.textFileLatestDate = + new Date();
        const fileNameWithDate = `${filenamePrefix}_${date}_${chunkNum}${filenameExtension}`;
        const _textFileHandle = await globalParams.directoryHandle.getFileHandle(fileNameWithDate, { create: true });
        db.putData(_textFileHandle, globalParams.dbKeyForCurrentFileHandle);
        return _textFileHandle;
    }

    async function* getFilesHandleRecursively(entry: FEntry): AsyncGenerator<FileSystemFileHandle> {
        if (entry.kind === 'file') {
            yield entry;
        } else if (entry.kind === 'directory') {
            for await (const handle of entry.values()) {
                yield* getFilesHandleRecursively(handle);
            }
        }
    }

    const rotateLogFile = async () => {
        const beforeMaxDays = globalParams.textFileLatestDate - globalParams.maxDaysToKeepFile * 86400000; // 24 * 3600 * 1000
        const rootDirHandle = await navigator.storage.getDirectory();
        for await (const fileHandle of getFilesHandleRecursively(rootDirHandle)) {
            const lastModified = (await fileHandle.getFile()).lastModified;
            if (lastModified < beforeMaxDays) {
                fileHandle.remove();
            }
        }
    }

    /* eslint-disable */
    self.onmessage = async (e) => {
        switch (e.data?.cmd) {
            case 'startWriteVideoFile':
                const timeSlice = 1000
                const recoderFileHandle: FileSystemFileHandle = e.data.fileHandle;
                const videoStream = e.data.videoStream;
                const audioStream = e.data.audioStream;
                const recorderOption = {
                    audioBitsPerSecond : 128000,
                    videoBitsPerSecond : 2500000,
                    mimeType: 'video/webm; codecs=vp9'
                }
        
                const allTracks = [...videoStream.getTracks(), ...audioStream.getAudioTracks()];
                
                const mixedStream = new MediaStream(allTracks);
                const mediaRecorder = new MediaRecorder(mixedStream, recorderOption);
                const recoderFileWritable = await recoderFileHandle.createWritable();

                mediaRecorder.ondataavailable = async e => {
                    console.log(e.data, 'recorder chunk');
                    recoderFileWritable.write(e.data);
                }

                mediaRecorder.onstop = async () => {
                    await recoderFileWritable.close();
                    const file = await recoderFileHandle.getFile();
                    console.log(file, 'recordered file');
                } 
                mediaRecorder.start(timeSlice);
                globalParams.mediaRecorder = mediaRecorder;
                break;

            case 'stopWriteVideoFile':
                globalParams.mediaRecorder.stop();
                break;

            case 'createLogFile':
                const directoryHandle = globalParams.directoryHandle || await navigator.storage.getDirectory();
                const { filenamePrefix, fileSizeQuota, maxDaysToKeepFile } = e.data;
                globalParams.filenameExtension = filenamePrefix;
                globalParams.filenamePrefix = filenamePrefix;
                globalParams.directoryHandle = directoryHandle;
                globalParams.fileSizeQuota = fileSizeQuota;
                globalParams.maxDaysToKeepFile = maxDaysToKeepFile;
                globalParams.dbKeyForCurrentFileHandle = `${filenamePrefix}_currentFileHandle`;
                const textFileHandle = globalParams.textFileHandle || await getFileHandle();
                textFileAccessHandle = await textFileHandle.createSyncAccessHandle();
                encoder = new TextEncoder();
                self.postMessage({
                    cmd: 'createLogFileReady'
                })
                globalParams.textFileHandle = textFileHandle;
                break;

            case 'logs':
                if (!textFileAccessHandle) {
                    console.warn('file writer has closed');
                    return;
                }
                let fileSize = await textFileAccessHandle.getSize();
                if (fileSize >= globalParams.fileSizeQuota) {
                    await saveFile();
                    const date = getDate();
                    if (date !== getDate(globalParams.textFileLatestDate)) {
                        // a new day, we need to rotate logs
                        rotateLogFile()
                    }
                    const fileHandle = await createNewFileHandle();
                    globalParams.textFileHandle = fileHandle;
                    textFileAccessHandle = await fileHandle.createSyncAccessHandle();
                    fileSize = 0;
                }
                const writeBuffer = encoder.encode(breakLine(addTimeStamp(e.data.text)));
                if (globalParams.syncAccessHandle) {
                    const accessHandle = globalParams.syncAccessHandle;
                    const fsize = await accessHandle.getSize();
                    await accessHandle.write(writeBuffer, { at: fsize });
                }
                textFileAccessHandle.write(writeBuffer, { at: fileSize });
                break;

            case 'clearOPFSFiles':
                {
                    const directoryHandle = await navigator.storage.getDirectory();
                    for await (const fileHandle of getFilesHandleRecursively(directoryHandle)) {
                        const permission = await verifyPermission(fileHandle, true);
                        if (permission) {
                            fileHandle.remove();
                        }
                    }
                    break;
                }

            case 'getOPFSFilesInfoByDate':
                {
                    const startDate = e.data.startDate;
                    const endDate = e.data.endDate;
                    const filesInfo = [];
                    const rootDirHandle = await navigator.storage.getDirectory();
                    for await (const fileHandle of getFilesHandleRecursively(rootDirHandle)) {
                        const file = await fileHandle.getFile();
                        const lastModified = file.lastModified;
                        if (lastModified > startDate && lastModified < endDate) {
                            filesInfo.push(file)                            
                        }
                    }

                    self.postMessage({
                        cmd: 'OPFSFilesInfo',
                        payload: filesInfo
                    })
                    break;
                }

            case 'saveLogFile':
                await saveFile();
                break;

            case 'moveOPFSFileByDate':
                const startDate = e.data.startDate;
                const endDate = e.data.endDate;
                const targetDirHandle = e.data.targetDirHandle;
                const rootDirHandle = await navigator.storage.getDirectory();
                for await (const fileHandle of getFilesHandleRecursively(rootDirHandle)) {
                    const lastModified = (await fileHandle.getFile()).lastModified;
                    if (lastModified > startDate && lastModified < endDate) {
                        if (!(globalParams.textFileHandle && await fileHandle.isSameEntry(globalParams.textFileHandle))) {
                            await fileHandle.move(targetDirHandle);
                        } else {
                            console.warn("current file can't be moved because it's not complete");
                        }
                    }
                }
                break;
            case 'moveOPFSFilesByName':
                {
                    const filename = e.data.filename;
                    const targetDirHandle = e.data.targetDirHandle;
                    const rootDirHandle = await navigator.storage.getDirectory();
                    const fileHandle = await rootDirHandle.getFileHandle(filename);
                    if (!(globalParams.textFileHandle && await fileHandle.isSameEntry(globalParams.textFileHandle))) {
                        await fileHandle.move(targetDirHandle);
                    } else {
                        console.warn("current file can't be moved because it's not complete")
                    }
                    break;
                }

            case 'writeRealTimeLog':
                {
                    const directoryHandle = await navigator.storage.getDirectory();
                    const tempLogFileHandle = await directoryHandle.getFileHandle('tempLog.txt', { create: true });

                    const reader = new FileReader();
                    const targetFileHandle = e.data.targetFileHandle;


                    reader.onload = async (event) => {
                        await globalParams.syncAccessHandle.truncate(0);
                        const writable = (await targetFileHandle.createWritable({ keepExistingData: true }));
                        const targetLogFile = await targetFileHandle.getFile();
                        console.log(targetLogFile.size, 'targetLogFile.size');
                        writable.write({ type: "write", position: targetLogFile.size, data: event.target.result });
                        await writable.close();
                    }

                    const syncAccessHandle = await tempLogFileHandle.createSyncAccessHandle();

                    globalParams.intervalHandle = setInterval(async () => {
                        const tempLogFile = await tempLogFileHandle.getFile();
                        reader.readAsArrayBuffer(tempLogFile);
                        reader.abort();
                    }, 1000);

                    globalParams.syncAccessHandle = syncAccessHandle;
                }
                break;

            case 'stopWriteRealTimeLog':
                clearInterval(globalParams.intervalHandle);
                globalParams.syncAccessHandle.flush();
                globalParams.syncAccessHandle.close();
                globalParams.syncAccessHandle = null;
                break;
            default:
                break;
        }
    }

    self.postMessage({
        cmd: 'initOK'
    })
}
